@@ -73,7 +73,8 @@ class MPImage():
                  mouse_events = False,
                  key_events = False,
                  auto_size = False,
-                 report_size_changes = False):
+                 report_size_changes = False,
+                 daemon = False):
         import multiprocessing
 
         self.title = title
@@ -96,11 +97,13 @@ class MPImage():
                                                  MPMenuItem('Full Zoom',  'Full Zoom', 'fullSize')])
 
         self.child = multiprocessing.Process(target=self.child_task)
+        self.child.daemon = daemon
         self.child.start()
         self.set_popup_menu(self.default_menu)
 
     def child_task(self):
         '''child process - this holds all the GUI elements'''
+        mp_util.child_close_fds()
         import wx
         state = self
 
@@ -169,6 +172,11 @@ class MPImage():
             ret.append(self.out_queue.get())
         return ret
 
+    def terminate(self):
+        '''terminate child process'''
+        self.child.terminate()
+        self.child.join()
+
 from PIL import Image
 
 class MPImageFrame(wx.Frame):
