@@ -153,7 +153,14 @@ class MPMenuSubMenu(MPMenuGeneric):
         '''add more items to a sub-menu'''
         if not isinstance(items, list):
             items = [items]
-        self.items.extend(items)
+        for m in items:
+            updated = False
+            for i in range(len(self.items)):
+                if self.items[i].name == m.name:
+                    self.items[i] = m
+                    updated = True
+            if not updated:
+                self.items.append(m)
 
     def combine(self, submenu):
         '''combine a new menu with an existing one'''
@@ -192,7 +199,14 @@ class MPMenuTop(object):
         '''add a submenu'''
         if not isinstance(items, list):
             items = [items]
-        self.items.extend(items)
+        for m in items:
+            updated = False
+            for i in range(len(self.items)):
+                if self.items[i].name == m.name:
+                    self.items[i] = m
+                    updated = True
+            if not updated:
+                self.items.append(m)
 
     def wx_menu(self):
         '''return a wx.MenuBar() for the menu'''
